package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````:!8``#0```!DD@````0`!30`(``'
M`"@`'``;``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!<````7````!`````$````!````````````````````I(P`
M`*2,```%```````!``$```"DC```I(P!`*2,`0"H`@``(`<```8```````$`
M`@```+",``"PC`$`L(P!`/````#P````!@````0````$````+`$``"P!```L
M`0``3````$P````$````!````%#E=&1TAP``=(<``'2'``#L````[`````0`
M```$````+W5S<B]L:6)E>&5C+VQD+F5L9E]S;P``!P````0````!````3F5T
M0E-$````RIH[!`````0````#````4&%8```````'````"0````4```!.971"
M4T0``&5A<FUV-VAF`````&$```!I```````````````Q````#@``````````
M````.`````\```!``````````#```````````P```$X```!A`````````!\`
M``!-````!@```!T````4`````````$,```!7````70`````````7````/```
M`%@```!B`````````&4```!G````+P```!(`````````10```!4```!<````
M1P````````!*````1@```#4```!;````)0```"H`````````!P```$\`````
M````#````"P```!H````6@```$P````@````4````&8`````````7P``````
M```8````+@```$$````````````````````1````,P`````````)````8```
M`%$````````````````````C````.0````````!2````!0```$@````;````
M.P````````````````````````!+`````````#H```!4````8P````````!D
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````$P``````````````
M`````````````````````````````````````"(````A`````````"D`````
M````"@```"<````H````+0``````````````#0````L````<````&@```!D`
M`````````````!``````````-````#(````W````'@``````````````````
M````````````!````````````````````$(````D````````````````````
M%@`````````_````1````"L````(```````````````^``````````````!6
M````)@`````````]``````````````!3`````````$D`````````````````
M``!5````60```#8```!>````````````````````````````````````:!8`
M```````#``L``````*R,`0```````P`1`)<``````````````!(````,````
M```````````2````%```````````````$@```'D#```8(```"````!(`"P`<
M```````````````B````*P``````````````$@```#$``````````````!(`
M``"*`P``3(\!```````0`!4`.```````````````$@```#X`````````````
M`!(```"8`P``1"H``!@````2``L`10``````````````$@```$\#````````
M`````!(```"S`P``$#8``%P````2``L`B```````````````$@```,<#``#$
MDP$``````!``%0!-```````````````2````OP,``$R/`0``````$``4`%T`
M`````````````!(```!L```````````````2````<@``````````````$@``
M`'D``````````````!(```"#```````````````2````C0``````````````
M$@```,8#``#$DP$``````!``%0"6```````````````2````X`(`````````
M````$@```)P``````````````!(```"C```````````````2````L0``````
M````````$@```,(``````````````!$```#/```````````````2````T@,`
M`)PB```H````$@`+`-\#``#$(@``*`$``!(`"P#K`P``N"L``+`'```2``L`
M$@,`````````````$@```-T``````````````!8```#P```````````````2
M````80,`````````````$@```/L``````````````!(````$`0``P),!``0`
M```1`!4`#`$`````````````$@```!4!`````````````!(```!%`P``````
M```````2````(0$`````````````$@```"@!`````````````!(```#X`P``
MR$(```@!```2``L`.P$`````````````$0```$T!`````````````!(```!=
M`0`````````````2````:P$`````````````$@```'`!`````````````!(`
M```#!```2(\!``0````1`!0`?P$`````````````$@```(L!````````````
M`!(```"@`0`````````````2````JP$`````````````$@```'0#``#$DP$`
M`````!``%0#X`@`````````````2````O@$`````````````$@```$8$``!H
M%@```````!(`"P#,`0`````````````2````U`$`````````````(@```.P!
M`````````````!(```#X`0`````````````2````#00``,23`0``````$``5
M`!4$``#L(P``G`4``!(`"P#^`0`````````````B````%`(`````````````
M$@```!\"`````````````!(````B!```T$,``%`!```2``L`,`(`````````
M````$@```"P$``!,CP$``````!``%0`X!```1!\``%P````2``L`0`0``/!%
M``"<`@``$@`+`#<"`````````````!(```!%!```:!8````````2``L`/@(`
M````````````$@```$4"`````````````!(```!-!```("```'P"```2``L`
M6@0``%PJ``!<`0``$@`+`&P$``"(*0``O````!(`"P!<`@`````````````2
M````V0(`````````````$@```&T"`````````````!(```!\`@``````````
M```2````A0(`````````````$@```(L"`````````````!(````X`P``````
M```````2````D`(`````````````$@```"L#``"$CP$`!````!$`%0"8`@``
M```````````2````5@,`````````````$@```)\"`````````````!(```!Z
M!```;$(``%P````2``L`I@(`````````````$@```+4"`````````````!$`
M```@`P``#(\!``0````1`!0`@P0``&@S``"H`@``$@`+`#0!````````````
M`!(```"Z`@`````````````2````:`,`````````````$@````!L:6)P97)L
M+G-O`')E86QL;V,`;65M;6]V90!?7V-X85]F:6YA;&EZ90!R;61I<@!S=')S
M='(`8VQO<V4`<W1R8VAR`'-T<FYC;7``8F]O=%]$>6YA3&]A9&5R`'!E<FQ?
M8V]N<W1R=6-T`&%B;W)T`'5N;&EN:P!?7VQS=&%T-3``<&5R;%]F<F5E`%]?
M<W1A=#4P`%]E>&ET`&UE;6-P>0!P97)L7V1E<W1R=6-T`%]?<W1A8VM?8VAK
M7V9A:6P`4$Q?9&]?=6YD=6UP`%!E<FQ?<W9?<V5T<'8`4$Q?8W5R<F5N=%]C
M;VYT97AT`'!E<FQ?86QL;V,`8VQO<V5D:7(`96YV:7)O;@!R96%D;&EN:P!?
M7V]P96YD:7(S,`!M96US970`4&5R;%]S869E<WES;6%L;&]C`%]?<W1A8VM?
M8VAK7V=U87)D`%!E<FQ?9W9?9F5T8VAP=@!?7W-P<FEN=&9?8VAK`')E860`
M4&5R;%]S>7-?:6YI=#,`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E
M>'0`4&5R;%]N97=84P!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S>7-?=&5R
M;0!?7V5R<FYO`%]?9&5R96=I<W1E<E]F<F%M95]I;F9O`%!E<FQ?;6=?<V5T
M`&UK9&ER`%]?<F5G:7-T97)?9G)A;65?:6YF;P!P97)L7W!A<G-E`%!E<FQ?
M;F5W6%-?9FQA9W,`86-C97-S`&=E='!I9`!M96UC:'(`4&5R;%]C<F]A:U]M
M96UO<GE?=W)A<`!097)L7V%T9F]R:U]L;V-K`%!E<FQ?<W9?<V5T<'9N`'!E
M<FQ?<G5N`&QS965K`&]P96X`<W!R:6YT9@!G971U:60`<W1R;&5N`%]?=&QS
M7V=E=%]A9&1R`%]?<T8`<W1R8VUP`&QI8FTN<V\N,`!L:6)C<GEP="YS;RXQ
M`'-T<F1U<`!F<')I;G1F`&QI8G!T:')E860N<V\N,0!P=&AR96%D7V%T9F]R
M:P!L:6)C+G-O+C$R`%]?<W1R;F-P>5]C:&L`7U]P<F]G;F%M90!?7W!S7W-T
M<FEN9W,`7U]G971P=W5I9#4P`%]?<WES8V%L;`!A=&5X:70`7VQI8F-?:6YI
M=`!S=')T;VL`7U]R96%D9&ER,S``7V5N9`!P87)?8W5R<F5N=%]E>&5C`%]?
M8G-S7W-T87)T7U\`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L
M96%N=7``7V5D871A`%]?8G-S7V5N9%]?`'!A<E]B87-E;F%M90!P87)?9&ER
M;F%M90!P87)?;6MT;7!D:7(`<VAA7W5P9&%T90!M>5]P87)?<&P`7U]E;F1?
M7P!P87)?:6YI=%]E;G8`<VAA7V9I;F%L`%]?8G-S7W-T87)T`'AS7VEN:70`
M;6%I;@!?7W-T87)T`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P
M87)?96YV7V-L96%N`'-H85]I;FET`%A37TEN=&5R;F%L<U]005)?0D]/5``O
M=7-R+W!K9R]L:6(O<&5R;#4O-2XS-BXP+V5A<FUV-VAF+6YE=&)S9"UT:')E
M860M;75L=&DO0T]213HO=7-R+W!K9R]L:6(```"DC`$`%P```*B,`0`7````
MM(X!`!<```#$C@$`%P```-2.`0`7````X(X!`!<```#DC@$`%P```/2.`0`7
M````_(X!`!<````$CP$`%P````B/`0`7````#(\!`!<````0CP$`%P```!B/
M`0`7````'(\!`!<````DCP$`%P```"B/`0`7````+(\!`!<````PCP$`%P``
M`#2/`0`7````/(\!`!<```!`CP$`%P```$B/`0`7````N(X!`!4'``#`C@$`
M%1,``,B.`0`5(0``S(X!`!$G``#0C@$`$B<``-R.`0`5,@``Z(X!`!4[``#L
MC@$`%4$``/".`0`51@``^(X!`!55````CP$`%6,``*R-`0`6`P``L(T!`!8$
M``"TC0$`%@4``+B-`0`6!P``O(T!`!8(``#`C0$`%@D``,2-`0`6"P``R(T!
M`!8,``#,C0$`%@X``-"-`0`6#P``U(T!`!81``#8C0$`%A4``-R-`0`6%@``
MX(T!`!87``#DC0$`%A@``.B-`0`6&0``[(T!`!8:``#PC0$`%AP``/2-`0`6
M'0``^(T!`!8>``#\C0$`%A\```".`0`6(```!(X!`!8B```(C@$`%B8```R.
M`0`6*```$(X!`!8I```4C@$`%BH``!B.`0`6+```'(X!`!8M```@C@$`%BX`
M`"2.`0`6+P``*(X!`!8P```LC@$`%C,``#".`0`6-```-(X!`!8U```XC@$`
M%C8``#R.`0`6.```0(X!`!8Y``!$C@$`%CH``$B.`0`6/0``3(X!`!8^``!0
MC@$`%D```%2.`0`600``6(X!`!9"``!<C@$`%D,``&".`0`61@``9(X!`!9'
M``!HC@$`%D@``&R.`0`62@``<(X!`!9.``!TC@$`%E```'B.`0`640``?(X!
M`!96``"`C@$`%E<``(2.`0`66```B(X!`!99``",C@$`%EH``)".`0`66P``
ME(X!`!9<``"8C@$`%EX``)R.`0`67P``H(X!`!9@``"DC@$`%F(``*B.`0`6
M9@``K(X!`!9G``"PC@$`%F@```3@+>4$X)_E#N"/X`CPON54>@$``,:/XA?*
MC.)4^KSE`,:/XA?*C.),^KSE`,:/XA?*C.)$^KSE`,:/XA?*C.(\^KSE`,:/
MXA?*C.(T^KSE`,:/XA?*C.(L^KSE`,:/XA?*C.(D^KSE`,:/XA?*C.(<^KSE
M`,:/XA?*C.(4^KSE`,:/XA?*C.(,^KSE`,:/XA?*C.($^KSE`,:/XA?*C.+\
M^;SE`,:/XA?*C.+T^;SE`,:/XA?*C.+L^;SE`,:/XA?*C.+D^;SE`,:/XA?*
MC.+<^;SE`,:/XA?*C.+4^;SE`,:/XA?*C.+,^;SE`,:/XA?*C.+$^;SE`,:/
MXA?*C.*\^;SE`,:/XA?*C.*T^;SE`,:/XA?*C.*L^;SE`,:/XA?*C.*D^;SE
M`,:/XA?*C.*<^;SE`,:/XA?*C.*4^;SE`,:/XA?*C.*,^;SE`,:/XA?*C.*$
M^;SE`,:/XA?*C.)\^;SE`,:/XA?*C.)T^;SE`,:/XA?*C.)L^;SE`,:/XA?*
MC.)D^;SE`,:/XA?*C.)<^;SE`,:/XA?*C.)4^;SE`,:/XA?*C.),^;SE`,:/
MXA?*C.)$^;SE`,:/XA?*C.(\^;SE`,:/XA?*C.(T^;SE`,:/XA?*C.(L^;SE
M`,:/XA?*C.(D^;SE`,:/XA?*C.(<^;SE`,:/XA?*C.(4^;SE`,:/XA?*C.(,
M^;SE`,:/XA?*C.($^;SE`,:/XA?*C.+\^+SE`,:/XA?*C.+T^+SE`,:/XA?*
MC.+L^+SE`,:/XA?*C.+D^+SE`,:/XA?*C.+<^+SE`,:/XA?*C.+4^+SE`,:/
MXA?*C.+,^+SE`,:/XA?*C.+$^+SE`,:/XA?*C.*\^+SE`,:/XA?*C.*T^+SE
M`,:/XA?*C.*L^+SE`,:/XA?*C.*D^+SE`,:/XA?*C.*<^+SE`,:/XA?*C.*4
M^+SE`,:/XA?*C.*,^+SE`,:/XA?*C.*$^+SE`,:/XA?*C.)\^+SE`,:/XA?*
MC.)T^+SE`,:/XA?*C.)L^+SE`,:/XA?*C.)D^+SE`,:/XA?*C.)<^+SE`,:/
MXA?*C.)4^+SE`,:/XA?*C.),^+SE`!"@X0(`H.$'T,WC,P``ZD0PG^5$()_E
M`S"/X'!`+>D\4)_E`F"3YP50C^`&`%7A<("]*`%@1N(`0*#C!6!&X"9AH.$$
M,)7D,_\OX08`5.$!0(3B^O__&G"`O>@8=P$`%`$``!!V`0!D()_E9#"?Y600
MG^4"((_@`P"2YP$PDN<#`%#A'O\O(?!!+>D!<$/B`'!'X`A0@.(`0*#CIW&@
MX0<``.H(8!7E"%"%X@`PEN4S_R_A!P!4X0%`A.(``(;E\(&]"`0P5>6@`%/C
M]/__"BC__^N\=@$`.`$``!P!``!P@9_E`&!1XH!`+>D(@(_@"-!-XDL```I<
M(9_E7#&?Y0(@F.<`8(+E"""6Y0-PF.<`,);E`""'Y0`@D^4``%+C.@``"C@1
MG^4!$)CG`""!Y0`@D^4`,-+E``!3XP4```H!((+B+P!3XP`@@04!,-+D``!3
MX_K__QH``%#C````"OO^_^N3___K^#"?Y0,PF.<``%/C-0``"NPPG^7L4)_E
M`Y"8YP50C^`)`%7A`9!),@6023``0*`S*9&@,00``"H$,)7D,_\OX0D`5.$!
M0(3B^O__&K@`G^6X4)_E``"/X./^_^NP,)_E!5"/X`.`F.<(`%7A`8!(,@6`
M2#``0*`S*(&@,00``"H$,)7D,_\OX00`6.$!0(3B^O__&@`@E^4`$);E!`"6
MY5X+`.NU_O_K3#"?Y60@G^4#,)CG`B"/X``@@^7+___J5#"?Y1/`H.,$`*#C
M`!"@XP,PC^`"(*#C`,"-Y?[^_^L!`*#CV/[_ZX3__^O'___J1'8!`%P!```T
M`0``9`$``%0!```D`0``L'0!`$S^__]L=`$`0`$``/1V`0#D+P``\$<MZ0"0
M4.+$,)_E`S"/X"L```J\()_E`C"3YP"`D^4``%CC*```"@!0V>4!<*#A``!5
MXST`51,!4*`3`%"@`Q$``!H`0)CE``!4XPP```H(8*#A!`"@X04@H.$)$*#A
MEO[_ZP``4.,"```:!3#4YST`4^,+```*!$"VY0``5./S__\:!`"@X?"'O>@)
M4*#A`3#UY0``4^,]`%,3^___&@E01>#F___J`5"%X@A@1N`%0(3@1F&@X0!@
MA^4$`*#A\(>]Z`E`H.'M___J"$"@X>O__^J<=`$`-`$``&`AG^5@,9_E`B"/
MX/!#+>D`4%#B`S"2YZ303>(`,)/EG#"-Y0`PH.,"```*`##5Y0``4^,*```:
M,"&?Y2@QG^4"((_@`S"2YP`@D^6<,)WE`B`SX``PH.-!```:I-"-XO"#O>B:
M_O_K`$!0XO'__PK\@)_E#7"@X0B`C^`$`*#A`O__ZP``4.,G```*#3#0Y0U@
M@.(N`%/C`@``&@$PUN4``%/C]/__"@TPT.4N`%/C(@``"@4`H.'H_O_K`)"@
MX08`H.'E_O_K``")X`(`@.+H_O_K!C"@X04@H.$($*#A`&"@X=3^_^L'$*#A
M!@"@X5/^_^L!`'#C!@"@X0,```H(,)WE#SH#X@$)4^,2```*0O[_ZP8`H.$W
M_O_K!`"@X=K^_^L``%#CU___&@0`H.%A_O_K!0"@X1W^_^N]___J`3#6Y2X`
M4^/9__\:`C#6Y0``4^/(__\*U?__ZJ?__^OK___J1?[_Z\1S`0`\`0``C',!
M`(PN``"0()_ED#"?Y0(@C^`00"WIH-!-X@,PDN<`0*#A#1"@X0`PD^6<,(WE
M`#"@XR#^_^L``%#C``"@$P0``!H(,)WE#SH#X@H*4^,!"5,3"@``"D@@G^5`
M,)_E`B"/X`,PDN<`()/EG#"=Y0(@,^``,*#C!P``&J#0C>(0@+WH`A"@XP0`
MH.%P_O_K$`]OX:`"H.'N___J&_[_ZTQR`0`\`0``_'$!`/!`+>D`8*#A^`"?
MY0';3>+T,)_E#-!-X@``C^`$<(WB`5"@X?\C`.,#,)#G!Q"@X=@`G^4`,)/E
M!#2-Y0`PH.,``(_@&/[_ZP#`4.(7``#:`4!,X@$[A.((,(/B`S"-X`0T4^4`
M`%/C(P``&@``5.,.```*!""@X2\0H.,'`*#A3O[_ZP``4.,(```*@`"?Y0``
MC^!M_O_K!#"@X0<@H.$&$*#A``"0Y4W^_^L&``#J8`"?Y0``C^!D_O_K!2"@
MX080H.$``)#EZ/W_ZT@@G^4T,)_E`B"/X`,PDN<`()/E!#2=Y0(@,^``,*#C
M!```&@';C>(,T(WB\("]Z`Q`H.';___JUOW_ZYAQ`0`\`0``L"P``$QR`0`H
M<@$`W'`!`/!'+>D!0*#A`##1Y0C03>(,$I_E`%"@X0@BG^4]`%/C`1"/X`%`
MA`+\@9_E`B"1YP0`H.$(@(_@`""2Y00@C>4`(*#C-O[_ZPT0H.$`8*#A!0"@
MX>/^_^L`D%#B00``"B_^_^L``%;A.```FKPQG^4`<)WE`X"8YP=QH.$`,-7E
M``!3XST`4Q,!,*`3`#"@`P4```H%,*#A`2#SY0``4N,]`%(3^___&@4P0^`"
M`(;B`&"8Y0,`@.`?_O_K``!0XP<`AN<6```*`!"=Y04`H.$`()CE`3#0Y`$1
MDN<``%/C/0!3$P`PP>4&```*`2"!X@$PT.0"$*#A``!3XST`4Q,!,,+D^?__
M&@$@H.$],*#C`##!Y0$PU.0``%/C`3#BY?O__QH((9_E^#"?Y0(@C^`#,)+G
M`""3Y00PG>4"(#/@`#"@XS4``!H(T(WB\(>]Z`&02>(!,-3D``!3XP$PZ>7[
M__\:[O__ZL`PG^4#@)CG`'"8Y0`PE^4``%/C)```"@<PH.$$(+/E"1"@X0&0
MB>(``%+C^O__&@,0@>(!$:#AD#"?Y0,PC^``()/E``!2XP\``!H!`*#A`2"@
MXP`@@^7=_?_K`*!0XM7__PH'$*#A"7&@X0<@H.$@_?_K`*"(Y0$PB>(`(*#C
M`R&*YP"0C>6A___J!P"@X17]_^L``%#C`*"@X0``B.7%__\*"7&@X?+__^H#
MD*#A"!"@X]___^I'_?_K<'`!`#P!``!<<`$`-`$``&1O`0#\<`$`0""?Y4`P
MG^5``)_E`B"/X'!`+>D``(_@`V"2Y[3]_^LL4)_E+$"?Y050C^`&(*#A!$"/
MX`4PH.$$$*#A<$"]Z```D.5B_?_J2&X!`"`!``!L;P$`T&<``'@I``!<`)_E
M,$`MZ0``C^`4T$WB4%"?Y9_]_^L%4(_@`$"@X0``D.7>___K`!"4Y3@@G^4`
M`*#C-#"?Y0P0C>4P$)_E`S"/X`(@E><!$(_@!`"-Y0`PC>4,`)WE8?W_ZQ30
MC>(P@+WH'&\!`.!M`0!H`0``T"L``"`I`````*#C'O\OX4`BG^5`,I_E\$\M
MZ0(@C^`3W4WB`&"@X0303>(L`I_E`S"2YR!PC>(``(_@`5"@X0001^(`,)/E
MO#2-Y0`PH.,B_O_K+Q"@XP!`H.$&`*#AR_S_ZP``4.,0```*\`&?Y080H.$`
M`(_@'O__ZP8`H.'@(9_ET#&?Y0(@C^`#,)+G`""3Y;PTG>4"(#/@`#"@XVL`
M`!H3W8WB!-"-XO"/O>@&`*#A6/W_ZZP1G^4!$(_@`("@X04`H.'G_/_K`+!0
MXN7__PJ4,9_EE*&?Y0,PC^`4,(WE`##;Y0J@C^"$D9_E``!3XPF0C^`U```*
M``!4XP0```H+$*#A!`"@X4O]_^L``%#C.0``"@L`H.$^_?_K`2!`X@(PB^`"
M(-OG+P!2XP4``!H`P*#C`,##Y0$`0.(!('/E+P!2X_K__PH!,(CB``"#X`$+
M4./#__^JO%"-XA0!G^4),*#A`2N@XP``C^``$*#C!`"-Y04`H.$(8(WE`+"-
MY=#\_^L'$*#A!0"@X9K\_^L``%#C`P``&B@PG>4/.@/B`@E3XQH```K,$)_E
M``"@XP$0C^"K_/_K`+"@X0``6^.H__\*`##;Y0``4^/)__\:``!4XQH```H`
M,-3E+@!3XP(```H4L)WE`0"@X]7__^H!,-3E``!3X_G__QI\$)_E``"@XP$0
MC^"6_/_K`+"@X>G__^H!$*#C!0"@X=;\_^L``%#CW___&E0`G^4%$*#A``"/
MX*[^_^L%`*#AVOS_ZXW__^H*L*#A`0"@X[W__^IX_/_K;&T!`#P!``#8*```
MJ"@```!M`0!P*```M"<``*@G```\*```("<``'@G```D)P``Z"8````PT.4`
M`%/C'O\O`0$@@.(O`%/C`@"@`0$PTN0``%/C^O__&A[_+^$00"WI`$!0XB\`
M``H`,-3E``!3XRP```K2_/_K`3!`X@,PA.`#`%3A`R"@,0,``#HI``#J!`!2
MX0(PH.$F```*`C"@X0$04N0O`%'C^/__"@,`5.$@```J`3!#X@,`5.$?```*
M`"#3Y2\`4N/Y__\:`3!#X@(``.H`$-+E+P!1XP,``!H#`%3A`R"@X0$P0^+X
M__\Z!"!"X`(P@N(!"U/C%@``BFP`G^4$$*#A`2""X@$[H.,``(_@!$"`X@0`
MH.$V_/_K!`"@X1"`O>A(`)_E$$"]Z```C^"'_/_J`P!4X>+__QH`,-3E+P!3
MXP4```HH`)_E$$"]Z```C^!^_/_J``"@XQ"`O>@4`)_E$$"]Z```C^!X_/_J
M,&P!``@E``#@)```S"0``"`EG^4@Q9_E(#6?Y0(@C^`,P(_@<$`MZ0S`C.(#
M,)+G,-!-X@C@C>($99_E`#"3Y2PPC>4`,*#C^%2?Y0\`O.@&8(_@!$"-X@50
MC^`/`*[H#P"\Z`\`KN@`,)SEL##.X000H.$&`*#A)?W_ZP``4.,.```*P#2?
MY000G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C
M!""#Y/O__QKK___JB&2?Y09@C^`$$*#A!@"@X0_]_^L``%#C#@``"F@TG^4$
M$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@
M@^3[__\:Z___ZC1DG^4&8(_@!!"@X08`H.'Y_/_K``!0XPX```H0-)_E!!"=
MY0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D
M^___&NO__^K@8Y_E!F"/X`00H.$&`*#AX_S_ZP``4.,.```*N#.?Y000G>4#
M,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O_
M_QKK___JC&.?Y09@C^`$$*#A!@"@X<W\_^L``%#C#@``"F`SG^4$$)WE`S"5
MYP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:
MZ___ZCACG^4&8(_@!!"@X08`H.&W_/_K``!0XPX```H(,Y_E!!"=Y0,PE><`
M()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO_
M_^KD8I_E!F"/X`00H.$&`*#AH?S_ZP``4.,.```*L#*?Y000G>4#,)7G`""3
MY0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___J
MD&*?Y09@C^`$$*#A!@"@X8O\_^L``%#C#@``"E@RG^4$$)WE`S"5YP`@D^4!
M,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___ZCQB
MG^4&8(_@!!"@X08`H.%U_/_K``!0XPX```H`,I_E!!"=Y0,PE><`()/E`3&"
MX`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO__^KH89_E
M!F"/X`00H.$&`*#A7_S_ZP``4.,.```*J#&?Y000G>4#,)7G`""3Y0$Q@N`$
M`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___JE&&?Y09@
MC^`$$*#A!@"@X4G\_^L``%#C#@``"E`QG^4$$)WE`S"5YP`@D^4!,8+@!`"3
MY0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___ZD`!G^4$$*#A
M``"/X#3\_^L`$%#B`@``"BP!G^4``(_@-?W_ZR0!G^4$$*#A``"/X"O\_^L`
M$%#B`@``"A`!G^4``(_@+/W_ZP@!G^4$$*#A``"/X"+\_^L`$%#B$@``"O0`
MG^4``(_@(_W_Z^P0G^7L`)_E`1"/X```C^`>_?_KX""?Y80PG^4"((_@`S"2
MYP`@D^4L,)WE`B`SX``PH.,7```:,-"-XG"`O>BX`)_E!!"@X0``C^`)_/_K
M`!!0X@,```JD`)_E``"/X`K]_^OE___JF!"?Y1D`C>(*(*#C`1"/X*[Z_^L`
M`%#CWO__&H``G^4C$(WB``"/X/[\_^O9___JS?K_ZZ!I`0!`8P``/`$``!PE
M``!D:0$`-`$``+0D``!D)```&"0``,@C``"`(P``R"(``-PB``"0(@``1"(`
M`'0A``"<(0``<"$``(PA``!8(```?"$``+`@``"((0``["````1E`0`H(0``
MN"```!`A``"((```G#"?Y9P0G^4#,(_@F""?Y03@+>4!$(_@``"3Y0S03>("
M()'G`0!PXP`@DN4$((WE`""@XPH```IP()_E:#"?Y0(@C^`#,)+G`""3Y00P
MG>4"(#/@`#"@XQ```!H,T(WB!/"=Y$@`G^4-$*#A``"/X+S[_^L``%#C!```
M"@``T.4P`%#C``!0$P$`H!,``*`#(#"?Y0,PC^```(/EY?__ZH?Z_^M\90$`
M_&,!`#P!``#08P$`F!\``/!D`0`00"WI\?K_Z^KZ_^L``%#C``"0%1"`O>@P
M(9_E\$`MZ0(@C^`H89_E%-!-XB0QG^4($(WB!F"/X`!0H.$#,)+G!@"@X0`P
MD^4,,(WE`#"@XY7[_^L`0%#B`@``"@`PU.4``%/C#@``&NP@G^7D,)_E`B"/
MX`,PDN<`()/E##"=Y0(@,^``,*#C+P``&LP`G^4%$*#A``"/X!30C>+P0+WH
MA_S_Z@40H.$F^O_K``!0XPH```JH()_EF#"?Y0(@C^`#,)+G`""3Y0PPG>4"
M(#/@`#"@XQP``!H4T(WB\("]Z`4`H.&_^O_K`'"@X00`H.&\^O_K``"'X`(`
M@.*_^O_K8#"?Y6`0G^4%(*#A`S"/X`!`C>4!$(_@`$"@X:CZ_^M(()_E+#"?
MY0(@C^`#,)+G`""3Y0PPG>4"(#/@`#"@XP00H`$&`*`!TO__"BWZ_^LT8P$`
ME!\``#P!``#D8@$`-!\``)AB`0#L'0``Z!T``"QB`0#P3RWI`)"@X10'G^6!
MW$WB$!>?Y3303>(``(_@@2R-X@0WG^4L((+B`1"0YQ-NC>(#,(_@$;Y&X@`0
MD>4`$(+E`!"@X^0FG^40X(/B*("#X@(@C^`4((WE!P"3Z?C`1N)!3T;B,'"-
MXA101^('`(OH#P"^Z`\`K.@#`)[H`P",Z`<`F.@'`(3H!1"@X:`&G^4``(_@
M)_O_ZP!`4.("```*`##4Y0``4^,0`0`:=O__ZP"P4.+T```*"P"@X6SZ_^N`
M`*#A`0"`XF_Z_^L`(-OE``!2XP"`H.$)```*5*:?Y0A`H.$*H(_@!`"@X0H0
MH.%6^O_K`2#[Y0)`A.(``%+C^/__&C`&G^7T0$;B``"/X`(``.H$`)3D``!0
MXPT```H%$*#A`_O_ZP"P4.+X__\*`##;Y0``4^/U__\*DOO_ZP``4./R__\*
M"P"@X2WZ_^L`0%#B$P``&A!P1^(`H*#C"B&&X!!!$N4``%3C#```"@&PBN(+
ML8?@`"#4Y0``4N,'```*!`"@X0&@BN)^^__K``!0XSL``!H$0)OD``!4X_3_
M_QH`0*#C!`"@X3#Z_^L`L*#A"`"@X2WZ_^L`L(O@`;N+X@2PB^(+`*#A+OK_
MZV@UG^5H%9_E!""@X0,PC^``,(WE7#6?Y0$0C^`$@(WE`S"/X`!PH.$4^O_K
M!QV@XP<`H.'G^?_K`0!PXXL```K@$$;B!P"@X8CY_^L`0%#B'0``"A3`G>4'
M,*#A&`6?Y0!0H.,4%9_E`""9Y0``G.<!$(_@L`"`XHCY_^L`%9_E@3R-XLPD
MG^4L,(/B`1"/X`(@D><`$)+E`""3Y0$0,N``(*#C*0$`&@4`H.&!W(WB--"-
MXO"/O>@$`*#AW?G_ZP!`4.*Q__\*PO__ZM@P%N4/.@/B`0E3X]W__QK$@!;E
MZ?G_ZP``6.'9__\:V#`6Y5,PZ.<'#5/CU?__&@L`H.'M^?_K!1"@X0!0H.%T
M!)_E``"/X)/Z_^L``%#CEP``"@"`F>7#^?_K`!"@X0@`H.%8_/_K`*!0XI``
M``H*`*#AU_G_ZP,`4.,`@*#A#```FC04G^4$`$#B``"*X`$0C^#8^?_K``!0
MXP4``!H$`%CCQ@``"@B`BN`%,%CE+P!3X\(```J=_O_K`!!0X@,``!H*`*#A
ML_G_ZP"`4.)Y```:Z!.?Y>@#G^4!$(_@Y).?Y0``C^#@@Y_E</O_Z]QCG^63
M^?_KV".?Y=@SG^4)D(_@U!.?Y0(@C^`#,(_@!""-Y0$0C^`'(*#A"("/X`9@
MC^```(WE!0"@X:#Y_^L-``#J:_G_ZP`PD.41`%/C#@``&G_Y_^L!0(3B"3"@
MX0<@H.$($*#A4`"-Z0#`H.$%`*#A`,"-Y9'Y_^L'':#C!0"@X63Y_^L!`'#C
M[/__"@<`H.'Z^/_K5`.?Y040H.$``(_@1OO_ZP4`H.&9_O_K@O__ZD_Y_^L`
M,)#E$0!3XV___PH`0)GE2OG_Z^P2G^4',*#A`%"@XP0@H.$`P)#E%`"=Y0$`
MD.<($Y_EL`"`X@#`C>4!$(_@^?C_ZV___^H$0$?B"Z"@X0HQAN`$`1/E``!0
MXR,```H!L(KB"X&$X`40H.$+H*#A'_K_ZP`P4.("```*`##3Y0``4^,$```:
M!`"8Y```4.,6```*`;"+XO+__^I(^?_K`+!0XNG__PKQ_O_J:_[_ZXP2G^4H
M(I_E@3R-X@$0C^`L,(/B`B"1YP`0DN4`()/E`1`RX``@H.-_```:!`"@X8'<
MC>(TT(WB\$^]Z#3Y_^H-`*#C3+*?Y5+Y_^M3(*#C"["/X`"`H.'B_O_J`*"9
MY6S__^H$0$;B`##@XQ$@X.,"D*#C`)"-Y2[Y_^L&(*#C!!"@X0@`H.'K^/_K
M!#!6Y0``4^,"```:`S!6Y4,`4^-````*`#"@XP`@H.,`,(WE"`"@X0`PH.,>
M^?_K/P0`ZP"0H.$"``#J!!"@X0D`H.%1!`#K`BF@XP00H.$(`*#AU?C_ZP`@
M4.+V___*"`"@X:2AG^5\^/_K"1"@X40`1N(PL$;BA@0`ZT6`1N(*H(_@,9!&
MX@M`H.$!(/CE!`"@X0H0H.$"0(3B"_G_ZP@`6>'X__\:`!"@XP"PC>4($$;E
M!R"@X501G^4%`*#A4#&?Y0$0C^`$$(WE2!&?Y0,PC^`!$(_@_/C_ZV[__^H$
M@)GE``!8XSG__PH(`*#A__C_ZP,`4.,U__^:'!&?Y00`0.(``(C@`1"/X`'Y
M_^L``%#C"*"@`2W__^H",%;E00!3X[O__QH!,%;E0P!3X[C__QH`,-;E2`!3
MX[7__QH!,-;E10!3X[+__QH`,.#C.2#@XP@`H.$`D(WETOC_ZP00H.$I(*#C
M"`"@X8_X_^NL()_EK#"?Y04`H.&H$)_E`B"/X`,PC^`$((WE`1"/X`<@H.$`
M0(WES/C_ZS[__^I;^/_KR&$!`#P!```D8P$`D&$!`-@<``"('0``X!L``*0<
M``",'```]!H``&`!``"$'```A%\!`#@<``#T&P``V!H``%0:``!(&0``F!L`
M`#P<``!4'```/!D``)`;```\&0``"!H``.!<`0`@&0``;!@``+09``"4%@``
MW!@``*`8``#X&```X!4``"08``!0(I_E4#*?Y0(@C^!,`I_E\$`MZ0S03>(#
M,)+G``"/X`U@H.$`,)/E!#"-Y0`PH..F^/_K!A"@X0`PD.4@`I_E9"#3Y0``
MC^!E(,/E3?G_ZP``4.,"```*`##0Y3$`4^-D```*!OS_Z_@!G^7X09_E``"/
MX)7X_^L$0(_@`S"@XP$@H.,$$*#A`%"@X0``D.4T^/_K`$!0X@H```H,,)3E
MR"&?Y0``E>4`$)/E`B"/X`[X_^L,,)3E`!"3Y0@PD>4!!1/C5P``&J0!G^6D
M09_E``"/X'WX_^L$0(_@`S"@XP$@H.,$$*#A`%"@X0``D.4<^/_K`$!0X@D`
M``IX`9_E!A"@X0``C^`>^?_K`"!0XCP```H,,)3E``"5Y0`0D^7R]__K5`&?
MY51QG^4``(_@9OC_ZTP1G^4!(*#C!W"/X`$0C^``4)#E`$"@X04`H.$0^/_K
M,"&?Y0(@C^``$*#A!0"@X>'W_^L`,)3E'`&?Y0`@H.,&$*#A``"/X&4@P^4`
M^?_K``!0XP@$A^41```*!QV@XQ?X_^L!((#B`#"@X1$`4.,!`%(3(@``BN`@
MG^6D,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``,*#C&```&@S0C>+P@+WH!`27
MY9O]_^L``%#C"`2'Y>C__QJD`)_E``"/X.KW_^L!,-#E``!3XYC__PJ6___J
MC#"?Y0P@E.4#,(_@!#23Y0``DN4`$)/EEOG_Z[[__^H``)7E[O?_ZZ3__^JJ
M]__K8""?Y6``G^4"((_@``"/X`04DN4())+E`!"1Y=+W_^LH6@$`/`$``$!;
M`0#$%0``[%H!`#P7```,%P``C%H!`.@6``#`%```,%H!``1;`0"$%@``A!8`
M`$`4``!\6`$`]!4``#!:`0``6@$`Q!4``'!`+>D`0*#A*?O_ZQ[[_^L`4*#A
MU_S_ZP``4.,``%03<("]"``PU.4``%/C<("]""`0G^4$(*#C!0"@X0$0C^!6
M]__K``!0XW"`O1@$`*#A<$"]Z-CX_^KL$P``\$\MZ5/?3>+DZY_E!#"-XN`K
MG^4<$(#B#N"/X%S`@.(`0*#A`P"@X0(@GN<`()+E1"&-Y0`@H.,$()'D`0!<
MX3(OO^8$((#D^O__&OP`@^(-(*#A`A"@X03`LN4X,)'E)."1Y0``4N$,$)'E
M#C`CX`$P(^`,,"/@XS^@X4`P@N7S__\:(%"4Z9DY!^,$`)WE@CI%XP!@E.40
M<)3E#A`LX`,`@.`%$`'@!P"`X&61H.$.$"'@"""=Y>8-@.!F@:#A`0"`X`D0
M+.`#((+@!A`!X`X@@N`,$"'@`A"!X`P@G>7@'8'@`R""X`R@@N`(("G@`"`"
MX&`!H.$)("+@"B""X!"@G>7A+8+@`Z"*X`F@BN``D"C@`9`)X&$1H.$(D"G@
M"I")X!2@G>7BG8G@`Z"*X`B@BN`!@"#@`H`(X&(AH.$`@"C@`K`AX`J`B.`8
MH)WE";`+X.F-B.`#H(K@`*"*X&D!H.$!D"O@`+`BX`J0B>`<H)WE"+`+X.B=
MB>`#H(K@`:"*X&@1H.$"@"O@`;`@X`J`B.`@H)WE";`+X.F-B.`#H(K@`J"*
MX&DAH.$`D"O@`K`AX`J0B>`DH)WE"+`+X.B=B>`#H(K@`*"*X&@!H.$!@"O@
M`+`BX`J`B.`HH)WE";`+X.F-B.`#H(K@`:"*X&D1H.$"D"O@`;`@X`J0B>`L
MH)WE"+`+X.B=B>`#H(K@`J"*X&@AH.$`@"O@`K`AX`J`B.`PH)WE";`+X.F-
MB.`#H(K@`*"*X&D!H.$!D"O@`+`BX`J0B>`TH)WE"+`+X.B=B>`#H(K@`:"*
MX&@1H.$"@"O@`;`@X`J`B.`XH)WE";`+X.F-B.`#H(K@`J"*X&DAH.$`D"O@
M`K`AX`J0B>`\H)WE"+`+X.B=B>`#H(K@`*"*X&@!H.$!@"O@`+`BX`J`B.!`
MH)WE";`+X.F-B.`#H(K@`:"*X&D1H.$"D"O@`;`@X`J0B>!$H)WE"+`+X.B=
MB>`#H(K@`J"*X&@AH.$`@"O@"H"(X$B@G>7IC8C@`Z"*X```BN`"H"'@":`*
MX&F1H.$!H"K@`*"*X$P`G>7HK8K@`P"`X`$`@.`)$"+@"!`!X&B!H.$"$"'@
M`!"!X%``G>7J'8'@`S"`X`@`*>`*``#@`B"#X`D`(."A.P[C`@"`X%0@G>79
M/D;C:J&@X0,@@N#A#8#@"9""X%@@G>4#((+@""""X`J`*.`!@"C@"(")X&&1
MH.%<$)WEX(V(X`,0@>`*$('@":`JX`"@*N!@`:#A"J""X&`@G>7HK8K@`R""
MX`D@@N``D"G@")`IX&B!H.$)D('@9!"=Y>J=B>`#$('@`!"!X`@`(.`*`"#@
M:J&@X0``@N!H()WEZ0V`X`,@@N`(((+@"H`HX`F`*.!ID:#A"("!X&P0G>7@
MC8C@`Q"!X`H0@>`)H"K@`*`JX&`!H.$*H(+@<""=Y>BMBN`#((+@"2""X`"0
M*>`(D"G@:(&@X0F0@>!T$)WEZIV)X`,0@>``$('@"``@X`H`(.!JH:#A``""
MX'@@G>7I#8#@`R""X`@@@N`*@"C@"8`HX&F1H.$(@('@?!"=Y>"-B.`#$('@
M"A"!X`F@*N``H"K@8`&@X0J@@N"`()WEZ*V*X`,@@N`)((+@`)`IX`B0*>!H
M@:#A"9"!X(00G>7JG8G@:K&@X0,0@>``$('@"``@X`H`(.``((+@Z:V"X(@@
MG>4#((+@""""X`N`*.`)`"C@:9&@X0`0@>",`)WEZHV!X`D0*^`#`(#@"A`A
MX`L`@."0L)WE:J&@X0$0@N`#L(O@Z!V!X`FPB^`*D"G@""`IX&B!H.$"((#@
MX9V"X)0@G>4#((+@"B""X`B@*N`!`"K@F*"=Y6$1H.$``(O@`Z"*X.D-@.`(
MH(K@`8`HX`F`*.!ID:#A"(""X)P@G>7@C8C@I+"=Y0,@@N`!((+@"1`AX``0
M(>!@`:#A`:"*X``0*>#HK8K@"!`AX`$@@N!H@:#AZAV"X*`@G>4#((+@"#`@
MX`D@@N!JD:#A`Z`JX-P\"^,;/TCC"B""X`.PB^`)H(CA`+"+X*@`G>7A+8+@
M`:`*X`,`@.!A$:#A"`"`X`F`".`(H(KA`8")X0N@BN`"@`C@`;`)X.*MBN`+
M@(CAL+"=Y0``B.!B(:#AZHV`X*P`G>4#L(O@`P"`X`&PB^`)D(#@`@"!X0H`
M`.`"$`'@`1"`X6JAH.$)D('@"A""X>@-B>"TD)WE"!`!X&B!H.$#D(G@`I")
MX`H@`N`"(('A"!"*X0NP@N``$`'@""`*X."]B^`"$('AN""=Y0D0@>"\D)WE
M8`&@X0,@@N`*H(+@`Y")X``@B.$(D(G@"R`"X`"`".#K'8'@"(""X6NQH.$*
MH(C@"R"`X6&!H.'AK8K@`2`"X,`0G>4#$('@`!"!X`L``.```(+A"""+X0D`
M@.`*(`+@")`+X.H-@.`)((+AR)"=Y0$0@N#$()WE:J&@X0.0B>`#((+@")")
MX`NP@N`*((CA`"`"X`J`".#@'8'@"(""X6`!H.$+L(C@`""*X6&!H.'AO8O@
M`2`"X,P0G>4#$('@"A"!X`"@"N`*H(+A"""`X0F0BN`+(`+@"*``X.N=B>`*
M((+AU*"=Y0$0@N#0()WE:[&@X0.@BN`#((+@"*"*X```@N`+((CA"2`"X`N`
M".#I'8'@"(""X6F1H.$``(C@"2"+X>&-@.`!(`+@80&@X=@0G>4#$('@"Q"!
MX`FP"^`+L(+A`"")X0J@B^`((`+@`+`)X.BMBN`+((+AX+"=Y0$0@N#<()WE
M:(&@X0.PB^`#((+@`+"+X`F0@N`(((#A"B`"X`@``.#J'8'@``""X6JAH.$)
MD(#@"B"(X6$!H.'AG8G@`2`"X.00G>4#$('@"!"!X`J`".`(@(+A`""*X0N`
MB.`)(`+@`+`*X.F-B.`+((+A[+"=Y0$@@N#H$)WE:9&@X0.PB^`#$('@`+"+
MX`J@@>`)$(#A"!`!X`D``.#H+8+@``"!X0J@@.!H@:#AX@V*X/"@G>4($(GA
M`S"*X`(0`>`),(/@8B&@X0B0">`"H(CA"1"!X0"@"N`+$('@`K`(X.`=@>`+
MH(KA8)&@X0,PBN#T`)WEX:V#X-8Q#.-B.DSC`P"`X&&QH.$(@(#@^`"=Y0,`
M@.`"`(#@"2`BX`$@(N#\$)WE`H"(X`L@*>#JC8C@"B`BX`,0@>!JH:#A"1"!
MX`J0*^`(D"G@`@"`X`F0@>`$$9WE`"&=Y>@-@.`#$('@:(&@X0H0@>`#((+@
M"*`JX`L@@N``H"K@X)V)X`J@@N`((9WE8`&@X>FMBN`#((+@""""X`"`*.`)
M@"C@:9&@X0B`@>`,$9WEZHV(X`,0@>``$('@"0`@X`H`(.!JH:#A``""X!`A
MG>7H#8#@`R""X`D@@N`*D"G@")`IX&B!H.$)D('@%!&=Y>"=B>`#$('@"A"!
MX`B@*N``H"K@8`&@X0J@@N`8(9WEZ:V*X`,@@N`(((+@`(`HX`F`*.!ID:#A
M"("!X!P1G>7JC8C@`Q"!X``0@>`)`"#@"@`@X&JAH.$``(+@("&=Y>@-@.`#
M((+@"2""X`J0*>`(D"G@:(&@X0F0@>`D$9WEX)V)X`,0@>`*$('@"*`JX`"@
M*N!@`:#A"J""X"@AG>7IK8K@`R""X`@@@N``@"C@"8`HX&F1H.$(@('@+!&=
MY>J-B.`#$('@`!"!X`D`(.`*`"#@:J&@X0``@N`P(9WEZ`V`X`,@@N`)((+@
M"I`IX`B0*>!H@:#A"1"!X#21G>7@'8'@`Y")X`J0B>`(H"K@`*`JX&`!H.$*
M((+@.*&=Y>$M@N`#H(K@"*"*X`"`*.`!@"C@81&@X0B0B>`\@9WEXIV)X`.`
MB.``@(C@`0`@X`(`(.!B(:#A``"*X`)PA^#I#8#@$'"$Y6#!C.`(P(3E0,&=
MY0,PC.`&,(/@`3"#X`(0(>`)$"'@:9&@X0$0B.`)("+@X!V!X``@(N`",(/@
M2""?Y0%0A>#A'8/@.#"?Y0(@C^`$4(3E">".X``0A.4,X(3E`S"2YP`@D^5$
M,9WE`B`SX``PH.,!```:4]^-XO"/O>AZ]/_K%%<!`#P!``!P2P$`$$`MZ6``
MH./R]/_K`""@XP'#`N.)&PKC1<=&X\T?3N,`P(#E_LP-XP00@.6ZR$GC=A0%
MXPC`@.4R$$'C%""`Y0P0@.7P$0[C&""`Y=(33.-<((#E$!"`Y1"`O>CP1RWI
M`I"@X10PD.6"(:#A`%"@X0%`H.$",)/@&""0Y10P@.4<@(7B7`"0Y0$@@B*I
M+H+@&""%Y0``4.,.```*0&!@X@``B.`&`%GA"6"@L08@H.%$]/_K7#"5Y0,P
MAN!<,(7E0`!3X_"'O1@%`*#A!I!)X`9`A.#)_/_K/P!9XQX``-I`D$GB*6.@
MX0%PAN('<X3@!!"@X4!`A.((,*#A`."1Y1`0@>(,P!'E$#"#X@@`$>4$(!'E
M!`!1X1#@`^4,P`/E"``#Y00@`^7S__\:!0"@X0%`H.&Q_/_K!P!4X>O__QH&
MDTG@"2"@X0<0H.$(`*#A'/3_ZUR0A>7PA[WH!'"@X??__^KP02WI''"!XA0@
MD>4!0*#A&&"1Y0!0H.'2,>7G,H^_Y@$@@^)_$.#C.`!2XS9OO^8"`(?@`Q#'
MYT```-I`(&+B`!"@XR?T_^L$`*#ADOS_ZU``P/(L,(3B#PI']`\*0_0\,(3B
M#PI#]$PPA.(/!T/T!`"@X51@A.58@(3EAOS_ZP,PU.4$`*#A`##%Y;(PU.$!
M,,7E`#"4Y2,TH.$",,7E`#"4Y0,PQ>4',-3E!##%Y;8PU.$%,,7E!#"4Y2,T
MH.$&,,7E!#"4Y0<PQ>4+,-3E"##%Y;HPU.$),,7E"#"4Y2,TH.$*,,7E"#"4
MY0LPQ>4/,-3E###%Y;XPU.$-,,7E##"4Y2,TH.$.,,7E##"4Y0\PQ>43,-3E
M$##%Y;(QU.$1,,7E$#"4Y2,TH.$2,,7E$#"4Y1,PQ>7P0;WHK?/_ZC@@8N(`
M$*#CYO/_Z\?__^I<,)_E$$`MZ0,PC^!40)_E)"#3Y01`C^```%+C$("]&$0@
MG^4!$*#C)!##Y0(PE.<``%/C`@``"C`PG^4#`)_G@_/_ZR@PG^4#,)3G``!3
MXQ"`O0@<`)_E$$"]Z```C^#P\__J6$H!`&1(`0`8`0``K$D!`$P!``!(0P``
M/!"?Y3PPG^4!$(_@`S"/X``@T>4``%+C'O\O$2@@G^4!`*#C``#!Y0(PD^<`
M`%/C'O\O`10`G^4$$('B``"/X.+S_^K<20$`\$<!`%`!``#L0@``1,*?Y40R
MG^5P0"WI#,"/X"#03>(X4I_E%`"-Y10`C>(0$(WE$!"-X@P@C>4,((WB`S"<
MYP50C^``,)/E'#"-Y0`PH..N\__K""*?Y0@RG^4"()7G`P"5YP(0H.&T\__K
M^#&?Y0,PE><`0-/E``!4XU$```KH`9_E``"/X/'S_^L48)WE`""0Y00`AN('
M`7#C`V"&XCXSTN4#,(/C/C/"Y6,``(H``:#AB?/_Z[0AG^400)WE`B"/X*P1
MG^4!$(_@!`2"Y0`PH.$`()3E`""`Y9@AG^4"((_@!""`Y9`AG^44`)WE`B"5
MYP$`4.,,$(/E`""2Y0@@@^5.``#:!!"$X@S`@^(`083@!."1Y`$`5.$$X*SE
M^___&@,`@.)449_E`!"@XP`0C>4&(*#A`!&#YP50C^!`$9_E#`25Y0$0C^"0
M\__K`$!0XB@```HL49_E&&"-X@50C^`,!)7E._/_ZQP!G^4&$*#A``"/X&/T
M_^L``%#C(0``"@@QG^4#,(_@#`23Y2+S_^ML\__K^""?Y;@PG^4"((_@`S"2
MYP`@D^4<,)WE`B`SX``PH.,E```:!`"@X2#0C>)P@+WH+_/_Z\@@G^4"((_@
M``!0XPP$@N4:```*`O/_Z[0`G^4``(_@F//_ZP`PD.7#1L/EH/__Z@P$E>5[
M\__K`$"@X=+__^H(!)7E``!0XP$```J#^__KV/__ZGP`G^4&$*#A``"/X#;T
M_^L``%#C"`2%Y='__PKU___J8O/_ZP0`H..V___J`0"@X\7R_^L#\__KG$<!
M`#P!``!T1P$`2`$``%@!```H`0``7$@!``1)`0`,!0``\`0``$0!``"(2`$`
M;-C__V1(`0`H`@``/$@!`!1&`0#T1P$`^$8!`!0!``!P<U]S=')I;F=S(&UI
M<W-I;F<*`"]T;7`O````+@```%!!4E]435!$25(``%1%35!$25(`5$U0`%53
M15(`````55-%4DY!344`````)7,O)7,````O<')O8R]C=7)P<F]C+V5X90``
M`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ
M0D]/5`````!005)?5$5-4`````!005)?4%)/1TY!344`````.@```"5S)7,E
M<P``4$523#5,24(`````4$523$Q)0@!015),-4]05`````!015),24\``%!!
M4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X```!005)?1$5"
M54<```!005)?0T%#2$4```!005)?1TQ/0D%,7T1%0E5'`````%!!4E]'3$]"
M04Q?5$U01$E2````4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`
M````4$%27T-,14%./0``,0```$Q$7TQ)0E)!4EE?4$%42`!365-414T``"4P
M,G@`````)7,E<R5S)7,`````<&%R+0`````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M
M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!0051(`````'!A
M<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P``
M`"5S)7-T96UP+25U+25U)7,`````&````'!E<FP`````,````%!!4CHZ4&%C
M:V5R.CI615)324].`````#$N,#4R````56YA8FQE('1O(&-R96%T92!C86-H
M92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@
M<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`````M90``+2T`
M`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII
M9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?
M7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1P87)?=&5M<"P@)'!R;V=N86UE
M+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%2
M7T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I
M;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M
M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN
M9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?
M=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D
M7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*
M5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE
M.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@
M/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT
M("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*
M<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@
M=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR
M;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I
M;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@
M)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@
M<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@
M?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F
M26YT97)N86QS.CI005(Z.D)/3U0["B1005)?34%'24,@/2`B7&Y005(N<&U<
M;B(["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6
M>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D
M7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H
M)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I
M+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@
M.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*
M;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!
M4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64@
M;W(@;&%S=#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY
M("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D;6%G:6-?<&]S.PII9B`H
M)'-I>F4@/#T@)&-H=6YK7W-I>F4I('L*)&UA9VEC7W!O<R`](#`["GT@96QS
M:68@*"AM>2`D;2`]("1S:7IE("4@)&-H=6YK7W-I>F4I(#X@,"D@>PHD;6%G
M:6-?<&]S(#T@)'-I>F4@+2`D;3L*?2!E;'-E('L*)&UA9VEC7W!O<R`]("1S
M:7IE("T@)&-H=6YK7W-I>F4["GT*=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@
M>PIS965K(%]&2"P@)&UA9VEC7W!O<RP@,#L*<F5A9"!?1D@L("1B=68L("1C
M:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@
M<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["B1M86=I8U]P;W,@
M*ST@)&D["FQA<W0["GT*)&UA9VEC7W!O<R`M/2`D8VAU;FM?<VEZ93L*?0IL
M87-T(&EF("1M86=I8U]P;W,@/"`P.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M
M(#0L(#`["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@)&UA9VEC7W!O
M<R`M(#0@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,#L*)&1A=&%?<&]S(#T@=&5L
M;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@
M("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)
M3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L
M;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA
M;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD
M77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I
M(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L
M("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*
M:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\
M86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L
M("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M
M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N
M86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO
M/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F
M:6QE;F%M92`](%]S879E7V%S*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U
M-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q
M=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD36]D=6QE0V%C:&5[)&9U;&QN86UE
M?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL
M;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@
M*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E
M9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`](&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1M;V1U;&5](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]
M("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y]
M(&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F
M:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[
M8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*
M;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I
M;F9O+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N
M("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD
M(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA
M;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H
M)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII
M9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA
M;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^
M("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI
M<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<
M,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@
M("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L
M("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM0
M05)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C
M=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"
M54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO
M<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B
M;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*
M<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@
M)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!
M4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L
M('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I
M('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@
M;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*
M?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@
M*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@
M*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@
M>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U
M;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@
M,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D
M,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*
M96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T
M*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T
M92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ
M1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU
M;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR
M97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER
M92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D
M>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G
M+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@
M)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ
M6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A
M<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R
M(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E96YV(#T@9&\@
M>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G3454
M02YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@
M<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*
M?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G
M+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@
M)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R
M(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@(E!+7#`P,UPP
M,#0B.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]
M($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)
M3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W
M-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=
M.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97([
M"FEF("AD969I;F5D("1D871A7W!O<RD@>PIR96%D(%]&2"P@)&QO861E<BP@
M)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R
M(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D
M97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A
M9&5R+"`D,"D["GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@
M>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D
M=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!
M4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H
M)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M
M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E
M="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*:68@*"1B=6YD;&4I
M('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`
M:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G
M<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@
M86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.
M0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*
M)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C
M=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I
M9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*
M;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE
M<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M
M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`
M:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F
M:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^
M(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO
M9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D[
M"FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]
M("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D
M969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT
M(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D
M+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E
M9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N
M=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT[
M"GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)&9H+"`G/#IR
M87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T[
M"B1C;VYT96YT(#T@/"1F:#X["F-L;W-E("1F:#L*4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*
M:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\
M:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P
M<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&
M24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B
M)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT
M*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT
M96YT*3L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"B1Z:7`M
M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@
M/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE
M(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]
M($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D
M;W5T.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E("1F:#L*)&-A8VAE7VYA
M;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X
M("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#
M04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A
M8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP
M<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U
M=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*
M7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A
M=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL
M("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E
M.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@
M<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R
M8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!
M4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@
M/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q6UPD
M14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*:68@*&1E9FEN
M960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@
M<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2![
M"FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M
M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA
M;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO
M;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI
M"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]
M($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T
M7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M
M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M
M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N
M86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?
M;F%M92(@=&\@(B1D97-T7VYA;64B72D["B1M96UB97(M/F5X=')A8W14;T9I
M;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@
M:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S
M86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@
M6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U
M=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA
M;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY
M("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B
M87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P
M87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I
M;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M
M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R![
M"G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT
M96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I
M<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR
M97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP
M.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I
M<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I
M;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER
M92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H
M0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#
M=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@
M4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP
M.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P
M='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/
M.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T
M7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%
M3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T
M=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@
M4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z
M7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H
M(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@
M)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I
M;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2![
M"B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I
M;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U
M<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-9
M4U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]
M("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E
M<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#
M3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2![
M"F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*<V5E:R`D9F@L("TQ."P@,CL*
M;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!
M0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIR96%D("1F:"P@)&)U9BP@-#$[
M"B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?6-A8VAE+21B=68B.PI]"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E
M<75I<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W
M*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q
M<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["B1C='@M/F%D9&9I;&4H
M)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M=&EM
M93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21D:6=E<W0B
M.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$[
M"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6
M>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@
M)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY
M("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE
M(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2![
M"FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@
M)SXZ<F%W)RP@)'1E;7!N86UE(&]R(&1I92!Q<5M#86XG="!W<FET92`B)'1E
M;7!N86UE(CH@)"%=.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@[
M"F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N
M86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE
M*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*
M:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]0
M4D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G
M;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R
M;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S
M=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P
M96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H
M.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N
M86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@
M)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%4
M2'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@
M97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM
M?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M
M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF
M("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?
M9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!2
M3T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D
M.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS
M,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@
M/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I
M9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]
M"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%
M1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)
M04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%
M0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD
M7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD
M14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X
M:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@
M/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.
M5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I
M9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU
M92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D[
M"B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!
M3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF
M("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I
M;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<[
M"G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG
M>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S
M:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C
M:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ
M9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N
M<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U
M8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*
M9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%
M6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@
M/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]
M?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z
M.E]?15)23U(["C$["E]?14Y$7U\*``!P97)L>'-I+F,```!?7T5.5E]005)?
M0TQ%04Y?7R`@("`@("`@("`@("`@(``````!&P,[Z````!P````$C___``$`
M`%R/__\<`0``U(___SP!``!\D?__C`$``%B2__^P`0``T)/__]P!``!TE/__
M``(``)25__\P`@``T)?__V`"```LF/__A`(``*28__^D`@``K)C__[@"```H
MF___\`(``%";__\$`P``>)S__S0#```4HO__7`,``-"B__]\`P``Z*+__Y0#
M``!$I/__S`,``/2K__\8!```G*[__T`$``#XKO__C`0``/BZ___`!```5+O_
M_]@$``!<O/___`0``*R]__]L`0``*+[__U@!``!\OO__9`0``!``````````
M`7I2``)\#@$;#`T`&````!@```#\C?__6`````!(#A"$!(4#A@*.`1P````T
M````.([__W@`````4@X8A`:%!88$AP.(`HX!&````%0```"0CO__J`$```!&
M#@B'`HX!1`X0`!````!P````R+S__U0`````````'````(0````XO/__?```
M``!$#@B$`HX!:L[$#@`````@````I````.B/___<`````$(.((0(A0>&!H<%
MB`2)`XH"C@$H````R````*"0__]X`0```$@.'(0'A0:&!8<$B`.)`HX!1@[`
M`6(*#AQ""R````#T````[)'__Z0`````2`X(A`*.`4(.J`%R"@X(0@L``"P`
M```8`0``;)+__R`!````0@X4A`6%!(8#AP*.`48.E`A$#J`(`G`*#A1""P``
M`"P```!(`0``7)/__SP"````0@X@A`B%!X8&AP6(!(D#B@*.`48.*`*>"@X@
M0@L``"````!X`0``:)7__UP`````2@X0A`2%`X8"C@%6SL;%Q`X``!P```"<
M`0``H)7__W@`````1`X,A`.%`HX!1`X@:`X,$````+P!``#XE?__"```````
M```T````T`$``.R5__]\`@```$8.)(0)A0B&!X<&B`6)!(H#BP*.`40.Y`E$
M#N@)`D`*#B1""P```!`````(`@``,)C__R@`````````+````!P"``!$F/__
M*`$```!"#@B$`HX!`F@*SL0.`$0+3@K.Q`X`1`M(SL0.````)````$P"```\
MF?__G`4```!,#A"$!(4#A@*.`48.0`-2`@H.$$(+`!P```!T`@``L)[__[P`
M````2@X$C@%&#A!@"@X$0@L`%````)0"``!,G___&`````!"#@B$`HX!-```
M`*P"``!,G___7`$```!$#A2$!84$A@.'`HX!1@XH>`H.%$+.Q\;%Q`X`0@M<
M"@X40@L```!(````Y`(``'"@__^P!P```$(.)(0)A0B&!X<&B`6)!(H#BP*.
M`48.I(("1`[8@@(#-@$*#B1""P-2`0H.)$+.R\K)R,?&Q<0.`$(+)````#`#
M``#4I___J`(```!*#A2$!84$A@.'`HX!0@X@`MX*#A1""R````!8`P``5*K_
M_UP`````0@X0A`2%`X8"C@%HSL;%Q`X``"0```!\`P``$+K__YP"````1@X0
MA`2%`X8"C@%$#C`"T@H.$$(+```P````I`,``&2J__\`#````$(.)(0)A0B&
M!X<&B`6)!(H#BP*.`4(.\`(#\@4*#B1""P``%````-@#```PMO__7`````!"
M#@B$`HX!(````/`#``!TMO__"`$```!"#B"$"(4'A@:'!8@$B0.*`HX!+```
M`!0$``!8M___4`$```!"#AB$!H4%A@2'`X@"C@$"G`K.R,?&Q<0.`$(+````
M`````)Q%```@10````````$````!`````0```,$"```!````RP(```$```#H
M`@```0````<#```/````F00``!D```"DC`$`&P````0````:````J(P!`!P`
M```$````!````'@!```%````.`L```8```"H!```"@```.($```+````$```
M`!4``````````P```*"-`0`"````$`(``!0````1````%P```"P1```1````
M'!```!(````0`0``$P````@```#[__]O````"/K__V\7````````````````
M`````````````````````````````````````````+",`0```````````#P3
M```\$P``/!,``#P3```\$P``/!,``#P3```\$P``/!,``#P3```\$P``/!,`
M`#P3```\$P``/!,``#P3```\$P``/!,``#P3```\$P``/!,``#P3```\$P``
M/!,``#P3```\$P``/!,``#P3```\$P``/!,``#P3```\$P``/!,``#P3```\
M$P``/!,``#P3```\$P``/!,``#P3```\$P``/!,``#P3```\$P``/!,``#P3
M```\$P``/!,``#P3```\$P``/!,``#P3```\$P``/!,``#P3```\$P``/!,`
M`#P3```\$P``/!,``#P3```\$P``/!,``#P3```\$P``/!,``*R,`0``````
M``````````"DC`$`````````````````P),!````````````J(P!`$B/`0``
M``````````````"PC`$``````(2/`0``````#(\!`&@S``"`CP$`$(\!`/__
M__^@2```J$@```````"L2```L$@``+A(```L20``P$@```````#$2```S$@`
M``````#$2P``1T-#.B`H3F5T0E-$(&YB,2`R,#(R,#<R,BD@,3`N-"XP`$=#
M0SH@*&YB,2`R,#(R,#<R,BD@,3`N-"XP`"1.971"4T0Z(&-R=#`N4RQV(#$N
M-"`R,#$X+S$Q+S(V(#$W.C,W.C0T(&IO97)G($5X<"`D`"1.971"4T0Z(&-R
M=#`M8V]M;6]N+F,L=B`Q+C(W(#(P,C(O,#8O,C$@,#8Z-3(Z,3<@<VMR;&P@
M17AP("0`)$YE=$)31#H@8W)T:2Y3+'8@,2XQ(#(P,3(O,#@O,3,@,#(Z-#DZ
M,#0@;6%T="!%>'`@)``D3F5T0E-$.B!C<G1B96=I;BYC+'8@,2XQ-R`R,#$X
M+S$R+S(X(#$X.C$W.C$Q(&-H<FES=&]S($5X<"`D`"1.971"4T0Z(&-R=&5N
M9"Y3+'8@,2XR(#(P,3,O,3(O,C`@,34Z,S4Z-#@@:F]E<F<@17AP("0`\<\"
M``````````````````@````(````"`````@````;`````0``````````*BHJ
M($YO($QA8F5L(%!R;W9I9&5D("HJ*@``\<\"``````````````````@````(
M````"`````@````;`````0``````````*BHJ($YO($QA8F5L(%!R;W9I9&5D
M("HJ*@!!,@```&%E86)I``$H````!3<M00`&"@=!"`$)`@H##`$2!!0!%0$7
M`Q@!&@(<`2(!1`$`+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N;F5T8G-D+FED
M96YT`"YN;W1E+FYE=&)S9"YP87@`+FYO=&4N;F5T8G-D+FUA<F-H`"YH87-H
M`"YD>6YS>6T`+F1Y;G-T<@`N<F5L+F1Y;@`N<F5L+G!L=``N=&5X=``N<F]D
M871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI
M7V%R<F%Y`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT
M`"Y354Y77V-T9@`N05)-+F%T=')I8G5T97,`+FYO:6YI=```````````````
M``````````````````````````````````````````L````!`````@```!0!
M```4`0``%P```````````````0`````````3````!P````(````L`0``+`$`
M`!@```````````````0`````````)@````<````"````1`$``$0!```4````
M```````````$`````````#<````'`````@```%@!``!8`0``(```````````
M````!`````````!*````!0````(```!X`0``>`$``#`#```&``````````0`
M```$````4`````L````"````J`0``*@$``"0!@``!P````,````$````$```
M`%@````#`````@```#@+```X"P``X@0``````````````0````````!@````
M"0````(````<$```'!```!`!```&``````````0````(````:0````D```!"
M````+!$``"P1```0`@``!@```!,````$````"````&T````!````!@```#P3
M```\$P``+`,`````````````!`````0```!R`````0````8```!H%@``:!8`
M`"0R``````````````0`````````>`````$````"````C$@``(Q(``#F/@``
M```````````$`````````(`````!`````@```'2'``!TAP``[```````````
M````!`````````".`````0````(```!@B```8(@``$0$``````````````0`
M````````F`````X````#````I(P!`*2,```$```````````````$````!```
M`*0````/`````P```*B,`0"HC```!```````````````!`````0```"P````
M`0````,```"LC`$`K(P```0```````````````0`````````M0````8````#
M````L(P!`+",``#P````!P`````````$````"````+X````!`````P```*"-
M`0"@C0``;`$`````````````!`````0```##`````0````,````,CP$`#(\`
M`$````````````````0`````````R0````@````#````@(\!`$R/``!$!```
M``````````!``````````,X````!````,`````````!,CP``/0``````````
M`````0````$````?`````0```#``````````B8\``!\!``````````````$`
M```!````UP````$``````````````*B0``"/```````````````$````````
M`.$````#``!P```````````WD0``,P```````````````0````````#Q````
M`0````$```#$DP$`:I$```````````````````$``````````0````,`````
?`````````&J1``#Y```````````````!````````````
